@@ -16,9 +16,13 @@
  ***************************************************************************/
 
 #include "config.h"
-#include <errno.h>
-#include <limits.h>
 
+#include <errno.h>
+
+#include <limits>
+#include <new>
+
+#include <QPointer>
 #include <QString>
 #include <QStringList>
 
@@ -96,7 +100,7 @@ int Kwave::MemoryPlugin::interpreteParameters(QStringList &params)
 	m_virtual_limit = param.toUInt(&ok);
 	if (!ok) return -EINVAL;
     } else {
-	m_virtual_limit = INT_MAX;
+	m_virtual_limit = std::numeric_limits<int>::max();
     }
 
     // parameter #5: directory for virtual memory files
@@ -127,8 +131,9 @@ void Kwave::MemoryPlugin::applySettings()
     Kwave::MemoryManager &mem = Kwave::MemoryManager::instance();
     mem.setPhysicalLimit(m_physical_limited ? m_physical_limit : 4096);
     mem.setVirtualLimit(m_virtual_enabled ?
-                       (m_virtual_limited ? m_virtual_limit : INT_MAX) :
-		       0);
+	(m_virtual_limited ? m_virtual_limit :
+	                     std::numeric_limits<int>::max()) :
+	0);
     mem.setSwapDirectory(m_virtual_directory);
     mem.setUndoLimit(m_undo_limit);
 }
@@ -141,18 +146,18 @@ QStringList *Kwave::MemoryPlugin::setup(QStringList &previous_params)
     // try to interpret the list of previous parameters, ignore errors
     if (previous_params.count()) interpreteParameters(previous_params);
 
-    Kwave::MemoryDialog *dlg = new Kwave::MemoryDialog(
+    QPointer<Kwave::MemoryDialog> dlg = new(std::nothrow) Kwave::MemoryDialog(
 	parentWidget(), m_physical_limited,
 	m_physical_limit, m_virtual_enabled, m_virtual_limited,
 	m_virtual_limit, m_virtual_directory, m_undo_limit);
     Q_ASSERT(dlg);
     if (!dlg) return Q_NULLPTR;
 
-    if (dlg->exec() == QDialog::Accepted) {
+    if ((dlg->exec() == QDialog::Accepted) && dlg) {
 	// get the new parameters and let them take effect
-	result = new QStringList();
+	result = new(std::nothrow) QStringList();
 	Q_ASSERT(result);
-	if (result) {
+	if (result && dlg) {
 	    dlg->params(*result);
 	    interpreteParameters(*result);
 	    applySettings();
